@@ -10,8 +10,7 @@ EdgeListSearch <- function (edgeList, dataset,
                           maxIter=100, maxHits=20, 
                           bestScore=NULL, stopAtScore=NULL, 
                           stopAtPeak=FALSE, stopAtPlateau=0L,
-                          forestSize=1L, 
-                          cluster=NULL, verbosity=1L, ...) {
+                          forestSize = 1L, verbosity = 1L, ...) {
   epsilon <- 1e-07
   if (!is.null(forestSize) && length(forestSize)) {
     if (forestSize > 1L) {
@@ -29,9 +28,14 @@ EdgeListSearch <- function (edgeList, dataset,
       bestScore <- edgeList[[3]]
     }
   }
-  if (verbosity > 0L) cat("\n  - Performing tree search.  Initial score:", bestScore)
+  if (verbosity > 0L) {
+    message("  - Performing tree search.  Initial score: ", bestScore)
+  }
   if (!is.null(stopAtScore) && bestScore < stopAtScore + epsilon) {
-    if (verbosity > 0L) cat("\n  - Aborting tree search as tree score", bestScore, "already below target of", stopAtScore)
+    if (verbosity > 0L) {
+      message("  - Aborting tree search as tree score ", bestScore, 
+              " already below target of ", stopAtScore)
+    }
     edgeList[[3]] <- bestScore
     return(edgeList)
   }
@@ -41,7 +45,7 @@ EdgeListSearch <- function (edgeList, dataset,
   
   for (iter in 1:maxIter) {
     candidateLists <- RearrangeEdges(edgeList[[1]], edgeList[[2]], dataset=dataset, 
-                             TreeScorer=TreeScorer, EdgeSwapper=EdgeSwapper, 
+                             TreeScorer = TreeScorer, EdgeSwapper=EdgeSwapper, 
                              hits=hits, iter=iter, verbosity=verbosity, ...)
     scoreThisIteration <- candidateLists[[3]]
     hits <- candidateLists[[4]]
@@ -66,26 +70,36 @@ EdgeListSearch <- function (edgeList, dataset,
         edgeList  <- candidateLists
         if (!is.null(stopAtScore) && bestScore < stopAtScore + epsilon) return(edgeList)
       } else if (stopAtPeak && scoreThisIteration > bestScore + epsilon) {
-        if (verbosity > 1L) cat("\n    ! Iteration", iter, "- No TBR rearrangement improves score.",
-                                scoreThisIteration, "doesn't beat", bestScore)
+        if (verbosity > 1L) {
+          message("    ! Iteration ", iter, 
+                  " - No TBR rearrangement improves score. ",
+                  scoreThisIteration, " doesn't beat ", bestScore)
+        }
         break
       }
       unimprovedSince <- unimprovedSince + 1L
       if (stopAtPlateau > 0L) {
-        if (verbosity > 2L && unimprovedSince > 0L) cat(" Last improvement", unimprovedSince, "iterations ago.")
+        if (verbosity > 2L && unimprovedSince > 0L) {
+          message(" Last improvement ", unimprovedSince, " iterations ago.")
+        }
         if (unimprovedSince >= stopAtPlateau) {
-          if (verbosity > 1L) cat("\n  - Terminating search, as score has not improved over past",
-                                unimprovedSince, "searches.")
+          if (verbosity > 1L) message("  - Terminating search, as score has ",
+                                      "not improved over past ",
+                                      unimprovedSince, " searches.")
           break
         }
       }
     }
     if (hits >= maxHits) {
-      if (verbosity > 1L) cat("\n  - Terminating search; hit best score", hits, "times.")
+      if (verbosity > 1L) message("  - Terminating search; hit best score ",
+                                  hits, " times.")
       break
     }
   }
-  if (verbosity > 0L) cat("\n  - Final score", bestScore, "found", hits, "times after", iter, "rearrangements\n")  
+  if (verbosity > 0L) {
+    message("  - Final score ", bestScore, " found ", hits, " times after ",
+            iter, " rearrangements.", if (verbosity > 1L) '\n' else '')
+  }
   
   if (forestSize > 1L) {
     if (hits < forestSize) forest <- forest[-((hits+1):forestSize)]
@@ -107,6 +121,11 @@ EdgeListSearch <- function (edgeList, dataset,
 #' Run standard search algorithms (\acronym{NNI}, \acronym{SPR} or \acronym{TBR}) 
 #' to search for a more parsimonious tree.
 #'  
+#' For detailed documentation of the TreeSearch package, including full 
+#' instructions for loading phylogenetic data into R and initiating and 
+#' configuring tree search, see the 
+#' [package documentation](https://ms609.github.io/TreeSearch).
+#'  
 #' @param tree a fully-resolved starting tree in \code{\link{phylo}} format, with the desired outgroup; edge lengths are not supported and will be deleted;
 #' @template datasetParam
 #' @template EdgeSwapperParam
@@ -130,6 +149,9 @@ EdgeListSearch <- function (edgeList, dataset,
 #' }
 #' @author Martin R. Smith
 #'
+#' @references
+#' - \insertRef{SmithTern}{TreeSearch}
+#'
 #' @seealso
 #' \itemize{
 #' \item \code{\link{Fitch}}, calculates parsimony score;
@@ -139,8 +161,8 @@ EdgeListSearch <- function (edgeList, dataset,
 #' }
 #'
 #' @examples
-#' data('Lobo')
-#' njtree <- NJTree(Lobo.phy)
+#' data('Lobo', package='TreeTools')
+#' njtree <- TreeTools::NJTree(Lobo.phy)
 #'
 #' \dontrun{
 #' TreeSearch(njtree, Lobo.phy, maxIter=20, EdgeSwapper=NNISwap)
@@ -149,6 +171,7 @@ EdgeListSearch <- function (edgeList, dataset,
 #' 
 #' @keywords  tree 
 #' @importFrom Rdpack reprompt
+#' @importFrom TreeTools RenumberTips
 #' @export
 TreeSearch <- function (tree, dataset,
                         InitializeData = PhyDat2Morphy,
@@ -163,20 +186,20 @@ TreeSearch <- function (tree, dataset,
     stop("tree must be bifurcating; try rooting with ape::root")
   }
   tree <- RenumberTips(tree, names(dataset))
-  edgeList <- MatrixToList(tree$edge)
-  edgeList <- RenumberEdges(edgeList[[1]], edgeList[[2]])
+  edgeList <- tree$edge
+  edgeList <- RenumberEdges(edgeList[, 1], edgeList[, 2])
 
   initializedData <- InitializeData(dataset)
   on.exit(initializedData <- CleanUpData(initializedData))
 
   bestScore <- attr(tree, 'score')
-  edgeList <- EdgeListSearch(edgeList, initializedData, TreeScorer=TreeScorer, 
+  edgeList <- EdgeListSearch(edgeList, initializedData, TreeScorer = TreeScorer, 
                              EdgeSwapper = EdgeSwapper, maxIter = maxIter, 
                              maxHits = maxHits, forestSize = forestSize, 
                              stopAtPeak = stopAtPeak, stopAtPlateau = stopAtPlateau,
                              verbosity = verbosity, ...)
   
-  tree$edge <- ListToMatrix(edgeList)
+  tree$edge <- cbind(edgeList[[1]], edgeList[[2]])
   attr(tree, 'score') <- edgeList[[3]]
   attr(tree, 'hits') <- edgeList[[4]]
   # Return:
