@@ -1,10 +1,11 @@
 #' Rearrange edges of a phylogenetic tree
 #' 
-#' Rearranges a matrix that corresponds to the edges of a phylogenetic tree,
-#' returning the score of the new tree.  Will generally be called from
-#' within a tree search function.
+#' `RearrangeEdges()` performs the specified edge rearrangement on a matrix 
+#' that corresponds to the edges of a phylogenetic tree, returning the score of
+#' the new tree.
+#' Will generally be called from within a tree search function.
 #' 
-#' @details \code{RearrangeTree} performs one tree rearrangement of a
+#' @details `RearrangeTree()` performs one tree rearrangement of a
 #'  specified type, and returns the score of the tree (with the given dataset).
 #'  It also reports the number of times that this score was hit in the 
 #'  current function call.
@@ -29,17 +30,17 @@
 #' 
 #' @examples
 #' data('Lobo', package='TreeTools')
-#' random.tree <- TreeTools::RandomTree(Lobo.phy)
-#' edge <- random.tree$edge
+#' tree <- TreeTools::NJTree(Lobo.phy)
+#' edge <- tree$edge
 #' parent <- edge[, 1]
 #' child <- edge[, 2]
 #' dataset <- PhyDat2Morphy(Lobo.phy)
-#' RearrangeEdges(parent, child, dataset, EdgeSwapper=RootedNNISwap)
-#' 
+#' RearrangeEdges(parent, child, dataset, EdgeSwapper = RootedNNISwap)
 #' @export
 RearrangeEdges <- function (parent, child, dataset, TreeScorer = MorphyLength,
-                            EdgeSwapper, scoreToBeat=TreeScorer(parent, child, dataset, ...),
-                            iter='?', hits=0L, verbosity=0L, ...) {
+                            EdgeSwapper, 
+                            scoreToBeat = TreeScorer(parent, child, dataset, ...),
+                            iter = '?', hits = 0L, verbosity = 0L, ...) {
   eps <- .Machine$double.eps ^ 0.5
   rearrangedEdges <- EdgeSwapper(parent, child)
   if (class(rearrangedEdges[[1]]) == 'list') {
